Contributing
------------

For information on how to contribute to Gertty, please see the
contents of the CONTRIBUTING.rst file.

Bugs
~~~~

Bugs are handled at: https://storyboard.openstack.org/#!/project/698
